@@ -21,6 +21,7 @@ from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
+    ClassVar,
     Dict,
     Generic,
     ItemsView,
@@ -134,12 +135,14 @@ default_faker = Faker()
 
 
 class ModelFactory(ABC, Generic[T]):  # noqa: B024
-    __model__: Type[T]
-    __faker__: Optional[Faker]
-    __sync_persistence__: Optional[Union[Type[SyncPersistenceProtocol[T]], SyncPersistenceProtocol[T]]] = None
-    __async_persistence__: Optional[Union[Type[AsyncPersistenceProtocol[T]], AsyncPersistenceProtocol[T]]] = None
-    __allow_none_optionals__: bool = True
-    __random_seed__: Optional[int] = None
+    __model__: ClassVar[Type[T]]  # type: ignore[misc]
+    __faker__: ClassVar[Optional[Faker]]
+    __sync_persistence__: ClassVar[Optional[Union[Type[SyncPersistenceProtocol[T]], SyncPersistenceProtocol[T]]]] = None  # type: ignore[misc]
+    __async_persistence__: ClassVar[  # type: ignore[misc]
+        Optional[Union[Type[AsyncPersistenceProtocol[T]], AsyncPersistenceProtocol[T]]]
+    ] = None
+    __allow_none_optionals__: ClassVar[bool] = True
+    __random_seed__: ClassVar[Optional[int]] = None
 
     @classmethod
     def seed_random(cls, seed: int) -> None:
@@ -160,7 +163,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         Field."""
         return isclass(value) and any(
             issubclass(value, c)
-            for c in [
+            for c in (
                 ConstrainedBytes,
                 ConstrainedDecimal,
                 ConstrainedFloat,
@@ -169,7 +172,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
                 ConstrainedList,
                 ConstrainedSet,
                 ConstrainedStr,
-            ]
+            )
         )
 
     @classmethod
@@ -330,7 +333,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
             with suppress(Exception):
                 return field_type()
         raise ParameterError(
-            f"Unsupported type: {repr(field_type)}"
+            f"Unsupported type: {field_type!r}"
             f"\n\nEither extend the providers map or add a factory function for this model field"
         )
 
@@ -351,9 +354,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
                 )
             if issubclass(outer_type, ConstrainedBytes):
                 return handle_constrained_bytes(field=cast("ConstrainedBytes", outer_type))
-            if issubclass(outer_type, (ConstrainedSet, ConstrainedList)) or (
-                issubclass(outer_type, ConstrainedFrozenSet)
-            ):
+            if issubclass(outer_type, (ConstrainedSet, ConstrainedList, ConstrainedFrozenSet)):
                 collection_type = list if issubclass(outer_type, ConstrainedList) else set
                 result = handle_constrained_collection(
                     collection_type=collection_type, model_field=model_field, model_factory=cls  # type: ignore
@@ -408,7 +409,9 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         )
 
     @classmethod
-    def get_field_value(cls, model_field: "ModelField", field_parameters: Union[dict, list, None] = None) -> Any:
+    def get_field_value(
+        cls, model_field: "ModelField", field_parameters: Optional[Union[Dict[Any, Any], List[Any]]] = None
+    ) -> Any:
         """Returns a field value on the subclass if existing, otherwise returns
         a mock value."""
         if model_field.field_info.const:
@@ -428,7 +431,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         if cls.is_constrained_field(outer_type):
             return cls.handle_constrained_field(model_field=model_field)
         if model_field.sub_fields:
-            return handle_complex_type(model_field=model_field, model_factory=cls)
+            return handle_complex_type(model_field=model_field, model_factory=cls, field_parameters=field_parameters)
         if is_literal(model_field):
             literal_args = get_args(outer_type)
             return random.choice(literal_args)
@@ -459,7 +462,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         if is_pydantic_model(pydantic_model_kwargs.__class__) or pydantic_model_kwargs is None:
             return False
         pydantic_model_fields = cls.get_model_fields(pydantic_model)
-        pydantic_model_field_names = set(dict(pydantic_model_fields).keys())
+        pydantic_model_field_names = {field_name for field_name, _ in pydantic_model_fields}
         kwargs_field_names = set(pydantic_model_kwargs.keys())
         return bool(pydantic_model_field_names - kwargs_field_names)
 
@@ -476,7 +479,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         if not is_pydantic_model(pydantic_model) or model_field.shape == SHAPE_MAPPING:
             return False
 
-        list_of_pydantic_models_kwargs = kwargs[field_name]
+        list_of_pydantic_models_kwargs = kwargs.get(field_name)
         if not isinstance(list_of_pydantic_models_kwargs, list):
             return cls._is_kwargs_missing_pydantic_fields(pydantic_model, list_of_pydantic_models_kwargs)
 
@@ -494,14 +497,13 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         """
         is_field_ignored = False
         is_field_in_kwargs = field_name in kwargs
+        is_partial_pydantic_model = cls._is_pydantic_with_partial_fields(field_name, model_field, **kwargs)
         if hasattr(cls, field_name):
             value = getattr(cls, field_name)
             if isinstance(value, Require) and not is_field_in_kwargs:
                 raise MissingBuildKwargError(f"Require kwarg {field_name} is missing")
             is_field_ignored = isinstance(value, Ignore)
-        return not is_field_ignored and (
-            not is_field_in_kwargs or cls._is_pydantic_with_partial_fields(field_name, model_field, **kwargs)
-        )
+        return not is_field_ignored and (not is_field_in_kwargs or is_partial_pydantic_model)
 
     @classmethod
     def get_model_fields(cls, model: Type[T]) -> ItemsView[str, "ModelField"]:
